@@ -1,90 +1,57 @@
 package Config::Natural;
 
 use strict;
-use Carp qw(carp croak);
 use File::Spec;
 use FileHandle;
 
 use vars qw($CLASS $VERSION);
 $CLASS   = 'Config::Natural';
-$VERSION = '0.99_06';
+$VERSION = '0.95';
+
+sub warning;
+sub fatal;
+
+my @base = (
+    options => {
+        'comment_line_symbol '    => '#', 
+        'affectation_symbol'      => '=', 
+        'multiline_begin_symbol'  => '-', 
+        'multiline_end_symbol'    => '.', 
+        'list_begin_symbol'       => '{', 
+        'list_end_symbol'         => '}', 
+        'include_symbol'          => 'include', 
+        'case_sensitive'          => 1, 
+        'auto_create_surrounding_list' => 1, 
+        'read_hidden_files'       => 0, 
+    }, 
+    state => {  }, 
+    param => {  }, 
+    handlers => {  }, 
+);
 
 # class option
 my %options = (
     quiet => 0, 
 );
 
+## set the accessors for the object options
+for my $option (keys %{$base[1]}) {
+    eval qq| sub $option { _get_set_option(shift, '$option', shift) } |;
+    warning "Initialisation error: $@ " if $@;
+}
+
 
 # 
 # new()
 # ---
 sub new {
     my $class = shift;
-    my $self = bless {
-        options => {
-            'comment_line_symbol'     => '#', 
-            'affectation_symbol'      => '=', 
-            'multiline_begin_symbol'  => '-', 
-            'multiline_end_symbol'    => '.', 
-            'array_begin_symbol'      => '(', 
-            'array_end_symbol'        => ')', 
-            'list_begin_symbol'       => '{', 
-            'list_end_symbol'         => '}', 
-            'include_symbol'          => 'include', 
-            'case_sensitive'          => 1, 
-            'auto_create_surrounding_list' => 1, 
-            'read_hidden_files'       => 0, 
-            'strip_indentation'       => 0, 
-        }, 
-        state => {  }, 
-        param => {  }, 
-        handlers => {  }, 
-        prefilter => 0, 
-        filter => 0, 
-    }, $class;
-    
-    if(ref $_[0] eq 'HASH') {
-        my $opts = shift;
-        for my $option (keys %$opts) {
-            $options{$option} = $opts->{$option} if exists $options{$option};
-            $self->{'options'}{$option} = $opts->{$option};
-            $self->filter($opts->{$option}) if $option eq 'filter';
-            $self->prefilter($opts->{$option}) if $option eq 'prefilter';
-        }
-    }
+    my $self = bless { @base }, $class;
     $self->read_source(shift) if @_;
     return $self;
 }
 
 
-# 
-# AUTOLOAD()
-# --------
-sub AUTOLOAD {
-    no strict;
-    my $self = $_[0];
-    my $type = ref $self || croak "I am not an object, so don't call me that way.";
-    my $name = $AUTOLOAD;
-    $name =~ s/.*:://;
-    
-    carp "Unknown option '$name'" 
-      unless exists $options{$name} or defined $self->{options}{$name};
-
-    my $code = q{
-        sub {
-            my $self = shift;
-            my $value = $self->{options}{METHOD};
-            $self->{options}{METHOD} = shift if @_;
-            return $value
-        }
-    };
-    $code =~ s/METHOD/$name/g;
-
-    *$AUTOLOAD = eval $code;
-    goto &$AUTOLOAD;
-}
-
-
 # 
 # DESTROY()
 # -------
@@ -95,6 +62,25 @@ sub DESTROY {
 }
 
 
+# 
+# _get_set_option()
+# ---------------
+sub _get_set_option {
+    my $self   = shift;
+    my $option = shift;
+    my $value  = shift;
+    
+    warning "Unknown option '$option' " unless exists $self->{options}{$option};
+    
+    if(defined $value) {
+        ($value, $self->{options}{$option}) = ($self->{options}{$option}, $value);
+        return $value
+    } else {
+        return $self->{options}{$option}
+    }
+}
+
+
 # 
 # options()
 # -------
@@ -104,14 +90,14 @@ sub options {
     my @ret_list = ();
     
     for my $arg (@{$args->{'get'}}) {
-        carp "Class option '$arg' does not exist" and next 
-            unless exists $options{$arg} or $options{'quiet'};
+        warning("Class option '$arg' does not exist ") and next 
+            unless exists $options{$arg};
         push @ret_list, $options{$arg};
     }
     
     for my $arg (keys %{$args->{'set'}}) {
-        carp "Class option '$arg' does not exist" and next 
-            unless exists $options{$arg} or $options{'quiet'};
+        warning("Class option '$arg' does not exist ") and next 
+            unless exists $options{$arg};
         $options{$arg} = $args->{'set'}{$arg};
     }
     
@@ -131,7 +117,7 @@ sub _read_dir {
     
     return $self->read_source($dir) if -f $dir;
     
-    opendir(DIR, $dir) or croak "Can't read directory '$dir': $!";
+    opendir(DIR, $dir) or fatal "Can't read directory '$dir': $!";
     my @list = grep {!/^\.\.?$/} readdir(DIR);  # remove . and ..
     @list = grep {!/^\./} @list unless $self->read_hidden_files;
     closedir(DIR);
@@ -165,35 +151,29 @@ sub read_source {
     }
     
     # ... else open the file
-    my $fh = _file_or_handle($file) or croak "Can't open file '$file': $!";
+    my $fh = _file_or_handle($file) or fatal "Can't open file '$file': $!";
     
     # keep local copy of the properties we'll use
-    my $comment   = $self->comment_line_symbol;
     my $aff_sym   = $self->affectation_symbol;
     my $multiline = $self->multiline_begin_symbol;
     my $multi_end = $self->multiline_end_symbol;
-    my $array     = $self->array_begin_symbol;
-    my $array_end = $self->array_end_symbol;
     my $list      = $self->list_begin_symbol;
     my $list_end  = $self->list_end_symbol;
     my $include   = $self->include_symbol;
     my $state     = $self->{'state'};
     
     # store the name of the last opened file
-    $state->{'filename'} = $file;
+    $state->{filename} = $file;
     
     while(defined($_ = <$fh>)) {
-        ## execute the prefilter if present
-        $self->{'prefilter'} and $_ = &{$self->{'prefilter'}}($self, $_);
-        
         next if /^\s*$/;  # skip empty lines
-        next if /^\s*$comment/;  # skip comments
+        next if /^\s*#/;  # skip comments
         chomp;
         
         ## include statement
         if(/^\s*\Q${include}\E\s+(\S+)\s*$/) {
             my $included = $1;
-            my @path = File::Spec->splitdir($state->{'filename'});
+            my @path = File::Spec->splitdir($state->{filename});
             pop @path;  # remove the current file name from the path
             $included = File::Spec->catdir(@path, $included);
             $self->read_source($included);
@@ -230,30 +210,12 @@ sub read_source {
             $value = '';
             $_ = <$fh>;
             
-            $self->strip_indentation and my($indent) = (/^(\s*)/);
-            
             while(not /^\s*\Q${multi_end}\E\s*$/) {
-                $indent and s/^$indent//;
                 $value .= $_;
                 $_ = <$fh>;
             }
         }
         
-        ## array case
-        if($value =~ /^\s*\Q${array}\E\s*$/) {
-            $value = '';
-            $_ = <$fh>;
-            
-            while(not /^\s*\Q${array_end}\E\s*$/) {
-                s/^\s*//;
-                $value .= $_;
-                $_ = <$fh>;
-            }
-            
-            $self->param({ $field => [ split $/, $value ] });
-            next
-        }
-        
         ## create a surrounding list if the parameter already exists
         if($self->auto_create_surrounding_list) {
             my $surrlist   = "${field}s";
@@ -312,8 +274,8 @@ sub param {
     
     ## get the value of the desired parameters
     for my $arg (@{$args->{'get'}}) {
-        carp "Parameter '$arg' does not exist" and next
-            if not exists $self->{'param'}{_case_($self, $arg)} and not $options{'quiet'};
+        warning("Parameter '$arg' does not exist ") and next
+            if not exists $self->{'param'}{_case_($self, $arg)};
         
         push @retlist, $self->{'param'}{_case_($self, $arg)}
     }
@@ -324,6 +286,10 @@ sub param {
     my @arg_list = keys %{$args->{'set'}};
     
     if($current_list) {
+        unless(exists $self->{'param'}{$current_list}) {
+            $self->{'param'}{$current_list} = []
+        }
+        
         $param = ${$self->{'state'}{'lists_stacks'}}[-1];
         
     } else {
@@ -333,15 +299,12 @@ sub param {
     for my $arg (@arg_list) {
         my $value = $args->{'set'}{$arg};
         
-        ## use the filter if present
-        $self->{'filter'} and
-            $value = &{$self->{'filter'}}($self, $value);
-        
-        ## use the handler if present
-        $self->{'handlers'}{$arg} and 
-            $value = $self->exec_handler($arg, $value);
-        
-        $param->{_case_($self, $arg)} = $value
+        ## check for a handler
+        if($self->has_handler($arg)) {
+            $param->{_case_($self, $arg)} = $self->exec_handler($arg, $value)
+        } else {
+            $param->{_case_($self, $arg)} = $value
+        }
     }
     
     return wantarray ? @retlist : $retlist[0]
@@ -377,7 +340,7 @@ sub _parse_args {
                 }
                 
             } else {
-                carp "Bad ref $ref_type; ignoring it" unless $options{'quiet'};
+                warning "Bad ref $ref_type; ignoring it ";
                 next
             }
         
@@ -386,8 +349,8 @@ sub _parse_args {
            if(substr($arg, 0, 1) eq '-') {
                $arg = substr($arg, 1);
                my $val = shift;
-               carp "Undefined value for parameter '$arg'" and next 
-                   if not defined $val and not $options{'quiet'};
+               warning("Undefined value for parameter '$arg' ") and next 
+                   if not defined $val;
                $args{'set'}{$arg} = $val if $arg
                
            ## getting the value of a parameter
@@ -401,32 +364,6 @@ sub _parse_args {
 }
 
 
-# 
-# prefilter()
-# ---------
-# Set a new prefilter. 
-# 
-sub prefilter {
-    my $self = shift;
-    my $code = shift;
-    croak "Not a CODEREF" unless ref $code eq 'CODE';
-    $self->{'prefilter'} = $code;
-}
-
-
-# 
-# filter()
-# ------
-# Set a new filter. 
-# 
-sub filter {
-    my $self = shift;
-    my $code = shift;
-    croak "Not a CODEREF" unless ref $code eq 'CODE';
-    $self->{'filter'} = $code;
-}
-
-
 # 
 # set_handler()
 # -----------
@@ -435,8 +372,8 @@ sub filter {
 sub set_handler {
     my $self = shift;
     my $param = shift;
-    my $code = shift;
-    $self->{'handlers'}{$param} = $code;
+    my $sub = shift;
+    $self->{'handlers'}{$param} = $sub;
 }
 
 
@@ -488,52 +425,6 @@ sub all_parameters {
 }
 
 
-# 
-# param_tree()
-# --------------
-# Return the hash tree of all parameters
-# 
-sub param_tree {
-    my $self = shift;
-    my $tree = {};
-    $tree->{$_} = $self->param($_) for($self->param());
-    return $tree;
-}
-
-
-# 
-# value_of()
-# --------
-# Return the value of the specified parameter
-# 
-sub value_of {
-    my $self = shift;
-    my $param_path = shift;
-    
-    # handle simple cases simply...
-    return $self->{'param'}{$param_path} if $self->{'param'}{$param_path};
-    
-    # handle more complex cases nicely.
-    my @path = split '/', $param_path;
-    not $path[0] and shift @path;
-    
-    my($name,$index) = ( (shift @path) =~ /^([^[]+)(?:\[([+-]?\d+|\*)\])?$/ );
-    my $node = $self->param($name);  $index ||= 0;
-    return $node if $index eq '*';
-    
-    if(ref $node) {
-        $node = $node->[int($index)];
-        for my $p (@path) {
-            ($name,$index) = ( ($p) =~ /^([^[]+)(?:\[([+-]?\d+|\*)\])?$/ );
-            $node = $node->{$name};  $index ||= 0;
-            ref $node and $index ne '*' and $node = $node->[int($index)];
-        }
-    }
-    
-    return $node
-}
-
-
 # 
 # delete()
 # ------
@@ -543,8 +434,8 @@ sub delete {
     my $self = shift;
     
     for my $param (@_) {
-        carp "Parameter '$param' does not exist" and next 
-            if not exists $self->{'param'}{_case_($self, $param)} and not $options{'quiet'};
+        warning("Parameter '$param' does not exist ") and next 
+            if not exists $self->{'param'}{_case_($self, $param)};
         delete $self->{'param'}{_case_($self, $param)}
     }
 }
@@ -589,69 +480,18 @@ sub dump_param {
     my $args = _parse_args(@_);
     my $prefix = $args->{'set'}{'prefix'} || '';
     my $suffix = $args->{'set'}{'suffix'} || '';
-    my $nospace = $args->{'set'}{'nospace'} || 0;
-
-    return _dump_tree($self, $self->{'param'}, 0, 
-        prefix => $prefix, suffix => $suffix, nospace => $nospace)
-}
-
-
-# 
-# _dump_tree()
-# ----------
-sub _dump_tree {
-    my $self = shift;
-    my $tree = shift;
-    my $level = shift;
-    my %state = @_;
     my $str = '';
-    my $sp = $state{'nospace'} ? '' : ' ';
     
-    if(ref $tree eq 'HASH') {
+    for my $param (sort $self->all_parameters) {
+        next unless $param;
+        ## multi-line value ?
+        my $multiline = 1 if $self->param($param) =~ /\n|\r/;
         
-        # add the list name and symbol
-        $state{'list_name'} and 
-        $str .= join '', 
-                $/, $sp x (($level-1)*2), $state{'list_name'}, $sp, 
-                $self->list_begin_symbol, $/;
-        
-        for my $param (sort keys %$tree) {
-            if(ref($tree->{$param})) {
-                $str .= _dump_tree($self, $tree->{$param}, $level+1, %state, list_name => $param)
-            
-            } else {
-                ## multi-line value?
-                my $multiline = 1 if $tree->{$param} =~ /\n|\r/;
-            
-                $str .= join '', 
-                        $sp x ($level*2), 
-                        $state{'prefix'}, $param, $sp, $self->affectation_symbol, $sp, 
-                        ($multiline ? $self->multiline_begin_symbol . $/ : ''), 
-                        $tree->{$param}, 
-                        ($multiline ? $self->multiline_end_symbol   . $/ : ''), 
-                        $state{'suffix'}, $/;
-            }
-        }
-       
-        # add the list end symbol
-        $state{'list_name'} and 
-        $str .= join '', 
-                $sp x (($level-1)*2), $self->list_end_symbol, $/;
-    
-    } elsif(ref $tree eq 'ARRAY') {
-        if(ref $tree->[0]) {
-            for my $list (@$tree) { $str .= _dump_tree($self, $list, $level, %state) }
-        } else {
-            $str .= join '', 
-                    $sp x ($level*2), 
-                    $state{'prefix'}, $state{'list_name'}, $sp,
-                    $self-> affectation_symbol, $sp, $self->array_begin_symbol, $/, 
-                    (map {($sp x (($level+1)*2)) . $_ . $/} @$tree), 
-                    $sp x ($level*2), $self->array_end_symbol, $/
-        }
-    
-    } else {
-        warn "unexpected reference type ", ref($tree)
+        $str .= join '', $prefix, $param, ' ', $self->affectation_symbol, ' ', 
+                ($multiline ? $self->multiline_begin_symbol . $/ : ''), 
+                $self->param($param), 
+                ($multiline ? $self->multiline_end_symbol   . $/ : ''), 
+                $suffix, $/;
     }
     
     return $str
@@ -671,14 +511,33 @@ sub write_source {
     
     my $file = shift;
     my $fh = _file_or_handle($file, 'w');
-    print $fh $self->dump_param(@_) or croak "Error while writing to '$file': $!";
+    print $fh $self->dump_param() or fatal "Error while writing to '$file': $!";
+}
+
+
+# 
+# warning()
+# -------
+sub warning {
+    my @caller = caller(2);
+    my $from = $caller[1] ? " at $caller[1] line $caller[2]" : "";
+    print STDERR "[$CLASS] ", @_, "$from\n" unless $options{quiet}
+}
+
+
+# 
+# fatal()
+# -------
+sub fatal {
+    my @caller = caller(2);
+    my $from = $caller[1] ? " at $caller[1] line $caller[2]" : "";
+    print STDERR "[$CLASS] ", @_, "$from\n" unless $options{quiet}
 }
 
 
 1;
 
 __END__
-
 =head1 NAME
 
 Config::Natural - Module that can read easy-to-use configuration files
@@ -862,7 +721,7 @@ but instead
     }
 
 I don't think it's a big deal, because the aim of Config::Natural 
-is to be fast and to read files with a clear and simple syntax. 
+is to be fast and read files with a clear and simple syntax. 
 
 
 =head2 Inclusion
@@ -887,99 +746,6 @@ sharp sign C<"#">, it will be ignored. The sharp sign needs not
 being in the first column though. 
 
 
-=head1 SPECIAL FEATURES
-
-=head2 Filters
-
-Config::Natural offer three filter mechanisms so that you can modify 
-the data on-the-fly at two differents moments of the parsing. 
-
-   file.txt             read_source()
-   ___________          _________________
-  | ...       | =====> | reading file    |
-  | foo=hello |        | > for each line |     _____________
-  | ...       |        |        X <======|==> |  prefilter  |
-  |___________|        |        v        |    |_____________|
-                       |   parsing line -|--,
-                       |_________________|  |
-                                            |
-                        param()  <----------'
-                        _________________      _____________
-                       |         X <=====|==> | data filter |
-                       |         v       |    |_____________|
-                       |         X <=====|==> |   handler   |
-                       |         v       |    |_____________|
-                       |  storing value  |
-                       |_________________|
-
-=head2 Prefilter
-
-Prefilter occurs before Config::Natural parsing, therefore a prefilter 
-receives the current line as it was read from the file. This can be 
-used in order to correct some names which otherwise couldn't be parsed 
-by Config::Natural, for example names with spaces. Check in the 
-F<examples/> directory for sample programs that implements such functions. 
-
-You can set up a prefilter using the C<-E<gt>prefilter()> method, or at 
-creation time with the C<prefilter> option. 
-
-=head2 Data filter
-
-Data filter only occurs when affecting values to their parameters. 
-This can be used to implement additional features, like a syntax 
-for interpolating values. Check in the F<examples/> directory for 
-sample programs that implements such functions. 
-
-You can set up a data filter using the C<-E<gt>filter()> method, or at 
-creation time with the C<filter> option. 
-
-
-=head2 Handlers
-
-Handlers only occurs when affecting values to their parameters, 
-but instead of being object methods, handlers can be seen as 
-"parameters" methods, in that they are bound to a name, and are 
-only called when a parameter with that name is affected. 
-
-Handlers are defined with the C<-E<gt>handler()> method. 
-
-
-=head1 PARAMETER PATH
-
-This is a new functionality, introduced in version 0.99. 
-
-A parameter path is a way of referring any parameter, even if 
-it's deeply buried inside several layers of nested lists. 
-It is used by the method C<-E<gt>value_of()> to provide a much 
-easier way to read data hidden in nested lists. 
-
-The parameter path syntax is loosely inspired by XPath:
-
-    path = /level0[index0]/level1[index1]/.../param
-
-Indexes start at zero, like in Perl (and unlike XPath). 
-When an index is omitted, C<[0]> is assumed. 
-
-Examples: 
-
-    # same as $config->param('myparam')
-    $value = $config->value_of('/myparam');
-    
-    # same as $config->param('list')->[0]{myparam}
-    $value = $config->value_of(/list[0]/myparam);
-    $value = $config->value_of(/list/myparam);
-
-If you want to get back a whole list, instead of a single value, 
-use C<[*]> as the last index, and it will return the reference to 
-that list. 
-
-    # same as $config->param('list')
-    $value = $config->value_of('/list[*]');
-    
-    # same as $config->param('list')->[0]{inner_list}
-    $value = $config->value_of('/list/inner_list[*]');
-
-
 =head1 OBJECTS OPTIONS
 
 =head2 Syntax Options
@@ -1031,45 +797,22 @@ Use this accessor to change the include symbol. Default is C<"include">.
 
 =over 4
 
+=item case_sensitive
+
+Use this accessor to change the case behaviour. Default is 1 (case sensitive). 
+
+
 =item auto_create_surrounding_list
 
 Use this accessor to enable or disable the auto creation of surrounding 
 lists. Default is 1 (enabled). 
 
 
-=item case_sensitive
-
-Use this accessor to change the case behaviour. Default is 1 (case sensitive). 
-
-
 =item read_hidden_files
 
 Use this accessor to allow of forbid Config::Natural to read hidden files 
 when reading a directory. Default is 0 (don't read hidden files). 
 
-
-=item strip_indentation
-
-Use this accessor to enable Config::Natural to automatically strip the 
-indentation from multilines values. For example, when this option is 
-enabled, the following: 
-
-    text = -
-        I thought what I'd do was. 
-        I'd pretend I was one of those deaf-mutes or should I?
-            --Laughing Man
-    .
-
-will be converted in
-    
-    text = -
-I thought what I'd do was. 
-I'd pretend I was one of those deaf-mutes or should I?
-    --Laughing Man
-    .
-
-This option is disabled by default. 
-
 =back
 
 
@@ -1079,23 +822,8 @@ This option is disabled by default.
 
 =item new ( )
 
-=item new ( [ OPTIONS, ] FILE )
-
-This method creates a new object. 
-
-You can give an optional hashref in order to change settings of the 
-object at creation time. Any valid object option can be used here. 
-
-    my $config = new Config::Natural { read_hidden_files => 1 };
-
-You can also give a file name or a file handle, which will call 
-read_source() with that argument. 
-
-    # calling with a file name
-    my $config = new Config::Natural 'myconfig.conf';
-    
-    # calling with a file handle
-    my $config = new Config::Natural \*DATA;
+This method creates a new object. You can give an optional parameter, in 
+which case the read_source() method is called with that parameter. 
 
 
 =item read_source ( I<FILENAME> )
@@ -1179,19 +907,6 @@ the value of the parameters of an object.
     );
 
 
-=item param_tree ( )
-
-This method returns a hashref that allows direct access to the tree 
-of parameters. 
-
-
-=item value_of ( PARAMETER_PATH )
-
-This method is an easier way to access the values of the parameters. 
-It returns the value of the parameter path given in argument. 
-Check L<"PARAMETER PATH"> for more information and some examples.
-
-
 =item all_parameters ( )
 
 This method returns the list of the parameters of an object.
@@ -1230,58 +945,26 @@ B<Options>
 
 =item *
 
-C<nospace> - If you set this option to true, no space will be printed 
-around the affectation symbol. 
-
-=item *
-
-C<prefix> - If you set this option to a string, it will be printed 
-before printing each parameter. 
+prefix - If you set this option to a string, it will be printed before printing 
+each parameter. 
 
 =item * 
 
-C<suffix> - If you set this option to a string, it will be printed 
-after printing each parameter. 
+suffix - If you set this option to a string, it will be printed after printing 
+each parameter. 
 
 =back
 
 
 =item write_source ( )
 
-=item write_source ( I<FILENAME> [, I<OPTIONS>] )
+=item write_source ( I<FILENAME> )
 
-=item write_source ( I<FILEHANDLE> [, I<OPTIONS>] )
+=item write_source ( I<FILEHANDLE> )
 
 This method writes the current object to the given file name or file 
-handle. Remaining parameters, if any, will be passed unmodified to 
-dump_param(). If no argument is given, the file or handle used by 
-the last call of read_source() will be used. 
-
-
-=item filter ( I<CODEREF> )
-
-This method can be used to set a new data filter. 
-The subroutine code will be considered as an object method and 
-will receive the data as it was read. The return value of the 
-function will be used as the actual value. 
-For example: 
-
-    sub myfilter {
-        my $self = shift;  # important! remember it's a method
-        my $data = shift;
-        $data =~ s/\s*#.*$//go;  # remove comments appearing on 
-        return $data          # an affectation line
-    }
-    
-    my $conf = new Config::Natural { filter => \&myfilter };
-
-
-=item prefilter ( I<CODEREF> )
-
-This method can be used to set up a new input prefilter. 
-The same rules as for data filters applies, the only difference 
-being in that the prefilter can modify the data before 
-Config::Natural parses it. 
+handle. If no argument is given, the file or handle used by the last 
+call of read_source() will be used. 
 
 
 =item set_handler ( I<PARAM, CODEREF> )
@@ -1319,7 +1002,7 @@ SE<eacute>bastien Aperghis-Tramoni <sebastien@aperghis.net>
 
 =head1 COPYRIGHT
 
-Config::Natural is Copyright (C)2000-2004 SE<eacute>bastien Aperghis-Tramoni.
+Config::Natural is Copyright (C)2000-2003 SE<eacute>bastien Aperghis-Tramoni.
 
 This program is free software. You can redistribute it and/or modify it 
 under the same terms as Perl itself. 
